<?php
/*
DMCA.com RESTful Badge Operationsbeta
API Reference
1. GetRegisteredBadges
2. GetAnonymousBadges
3. GetAuthenticatedBadges
4. RegisterNewAccount
5. CreateWaterMarkerToken
6. CreateWaterMarkerProToken
7. GetWaterMarkerToken
8. DeleteWaterMarkerToken
9. UpdateWaterMarkerToken
10. UpdateWaterMarkerProToken
11. ResetWaterMarkerToken
12. GetWaterMarkerTokens
Endpoints
https://www.dmca.com/rest - currently only available in https
*/

if ( !defined('DMCA_RESTFULL_API_URL') )
	define('DMCA_RESTFULL_API_URL', 'https://www.dmca.com/rest/' ); //

/**
* GetRegisteredBadges 
* Returns xml string of embed codes, requires valid AccountID (guid as string)
* Syntax public string 
* GetRegisteredBadges ( string AccountID )
* Parameters
* AccountID type: string
* Return Value
* Type: string
* Remarks
* None
* HTTP Method: GET
* Example: https://www.dmca.com/rest/GetRegisteredBadges?AccountID=0fd34f18-12b0-49de-9673-c3b5fde89593
* @since      2012-04-08
*/
function GetRegisteredBadges($AccountID) {
	$url = DMCA_RESTFULL_API_URL . 'GetRegisteredBadges';
	$response = wp_remote_request( $url, array(
		'timeout' 		=> '30',
		'redirection' 	=> '5',
		'method' => 'GET',
		'headers' => array('content-type' => 'application/json; charset=utf-8'),
		'body' =>  '{"AccountID":' . $AccountID . '}',
		'blocking'		=> true,
		'compress'		=> false,
		'decompress'	=> true,
		'sslverify' => false,
	));
	if( wp_remote_retrieve_response_code( $response ) == 200 ){
		$body = wp_remote_retrieve_body( $response );
		if( $body == '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">Login failed</string>' ){
			return false;
		}
		return html_entity_decode( $body );
	} else{
		return false;
	}
}

/**
* GetAnonymousBadges 
* Returns xml string of embed codes with no registration
* Syntax public string 
* GetAnonymousBadges()
* Parameters none
* Return Value
* Type: string
* Remarks Returns xml string of embed codes with no registration to DMCA.coms protection program. This is for people who just want the badge.
* HTTP Method: GET
* Example: https://www.dmca.com/rest/GetAnonymousBadges
* @since      2012-04-08
*/
function GetAnonymousBadges() {
	$url = DMCA_RESTFULL_API_URL . 'GetAnonymousBadges';
	$response = wp_remote_request( $url, array(
		'timeout' 		=> '30',
		'redirection' 	=> '5',
		'method' => 'GET',
		'headers' => array('content-type' => 'application/json; charset=utf-8'),
		'blocking'		=> true,
		'compress'		=> false,
		'decompress'	=> true,
		'sslverify' => false,
	));
	if( wp_remote_retrieve_response_code( $response ) == 200 ){
		$body = wp_remote_retrieve_body( $response );
		if( $body == '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">Login failed</string>' ){
			return false;
		}
		return html_entity_decode( $body );
	} else{
		return false;
	}
}

/**
* GetAuthenticatedBadges 
* Authenticates an existing user and returns xml string of embed codes.
* Syntax public string 
* GetAuthenticatedBadges ( string Email , string Password )
* Parameters
* Email type: string 
* Password type: string
* Return Value
* Type: string
* Remarks
* - Requires JSON formatted Request Body
* - Requests should be made with the following request headers - Content-type: application/json; charset=utf-8
* - Requires a valid email address and password
* - HTTPS is required for this operation
* HTTP Method: POST
* Example:
* - URL: https://www.dmca.com/rest/GetAuthenticatedBadges
* - Request Headers: Content-type: application/json; charset=utf-8
* - Request Body: {"Email":"JohnDoe@acme.com","Password":"test123"}
* @since      2012-04-08
*/
function GetAuthenticatedBadges($Email, $Password) {
	$url = DMCA_RESTFULL_API_URL . 'GetAuthenticatedBadges';
	$response = wp_remote_request( $url, array(
		'timeout' 		=> '30',
		'redirection' 	=> '5',
		'method' => 'POST',
		'body' =>  '{"Email":"' . $Email . '", "Password":"' . $Password . '"}',
		'headers' => array('content-type' => 'application/json; charset=utf-8'),
		'blocking'		=> true,
		'compress'		=> false,
		'decompress'	=> true,
		'sslverify' => false,
	));
	
	if( wp_remote_retrieve_response_code( $response ) == 200 ){
		$body = wp_remote_retrieve_body( $response );
		if( $body == '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">Login failed</string>' ){
			return false;
		}
		return html_entity_decode( $body );
	} else{
		return false;
	}
}

/**
* RegisterNewAccount
* Registers a new user and returns xml string of embed codes.
* Syntax public string 
* GetRegisteredBadges (string FirstName , string LastName , string Email , string CompanyName) )
* Parameters
* FirstName type: string 
* LastName type: string 
* Email type: string 
* CompanyName type: string
* Return Value
* Type: string
* Remarks
* - Requires JSON formatted Request Body
* - Requests should be made with the following request headers - Content-type: application/json; charset=utf-8
* - Requires a valid & unique email address.
* - Confirmation email with login instructions & password will be sent to addressee
* HTTPS is required for this operation
* HTTP Method: POST
* Example:
* - URL: https://www.dmca.com/rest/RegisterNewAccount
* - Request Headers: Content-type: application/json; charset=utf-8
* - Request Body: {"FirstName":"John","LastName":"Doe","CompanyName":"ACME","Email":"JohnDoe@acme.com"}
* @since      2012-04-08
*/
function RegisterNewAccount($FirstName, $LastName, $CompanyName, $Email) {
	$url = DMCA_RESTFULL_API_URL . 'RegisterNewAccount';
	$response = wp_remote_request( $url, array(
		'timeout' 		=> '30',
		'redirection' 	=> '5',
		'method' => 'POST',
		'body' =>  '{"FirstName":"' . $FirstName . '", "LastName":"' . $LastName . '","CompanyName":"' . $CompanyName . '", "Email":"' . $Email . '"}',
		'headers' => array('content-type' => 'application/json; charset=utf-8'),
		'blocking'		=> true,
		'compress'		=> false,
		'decompress'	=> true,
		'sslverify' => false,
	));
	
	if( wp_remote_retrieve_response_code( $response ) == 200 ){
		$body = wp_remote_retrieve_body( $response );
		if( $body == '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">Login failed</string>' ){
			return false;
		}
		return html_entity_decode( $body );
	} else{
		return false;
	}
}

/**
* CreateWaterMarkerToken
* Creates and returns a new WaterMarker token id.
* Syntax public string 
* CreateWaterMarkerToken (string Email , string Password , string Root , string Text )
* Parameters
* Email type: string 
* Password type: string 
* Root type: string 
* Text type: string
* Return Value
* Type: string
* Remarks
* - Requires JSON formatted Request Body
* - Requests should be made with the following request headers - Content-type: application/json; charset=utf-8
* - Requires a valid email address.
* - HTTPS is required for this operation
* HTTP Method: POST
* Example:
* - URL: https://www.dmca.com/rest/CreateWaterMarkerToken
* - Request Headers: Content-type: application/json; charset=utf-8
* - Request Body:
* - Successful result {"d":"wmt2b2a6c0"}
* - Failure Result: {"d":"ERROR: Error creating Watermarker Token"}
* {"Username":"test2@dmca.com","Password":"test","Root":"http://www.testsite.com/root","Text":"This is the test copyright text"}
* @since      2012-04-08
*/
function CreateWaterMarkerToken($Username, $Password, $Root, $Text) {
	$url = DMCA_RESTFULL_API_URL . 'CreateWaterMarkerToken';
	$response = wp_remote_request( $url, array(
		'timeout' 		=> '30',
		'redirection' 	=> '5',
		'method' => 'POST',
		'body' =>  '{"Username":"' . $Username . '", "Password":"' . $Password . '", "Root":"' . $Root . '", "Text":"' . $Text . '"}',
		'headers' => array('content-type' => 'application/json; charset=utf-8'),
		'blocking'		=> true,
		'compress'		=> false,
		'decompress'	=> true,
		'sslverify' => false,
	));
	
	if( wp_remote_retrieve_response_code( $response ) == 200 ){
		$body = wp_remote_retrieve_body( $response );
		if( $body == '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">Login failed</string>' ){
			return false;
		}
		return html_entity_decode( $body );
	} else{
		return false;
	}
}

/**
* CreateWaterMarkerProToken
* Creates and returns a new WaterMarker Pro token id.
* Syntax public string 
* CreateWaterMarkerProToken (string Email , string Password , string Root , string Text , int BarOpacity , int LogoOpacity , int Position , string LogoUrl )
* Parameters
* Email type: string 
* Password type: string 
* Root type: string 
* Text type: string 
* BarOpacity type: string 
* LogoOpacity type: string 
* Position type: string 
* LogoUrl type: string
* Return Value
* Type: string
* Remarks
* - Requires JSON formatted Request Body
* - Requests should be made with the following request headers - Content-type: application/json; charset=utf-8
* - Requires a valid email address.
* - HTTPS is required for this operation
* HTTP Method: POST
* Example:
* - URL: https://www.dmca.com/rest/CreateWaterMarkerProToken
* - Request Headers: Content-type: application/json; charset=utf-8
* - Request Body:
* - Position must be a number between 1 and 4.
* 1. Indicating top left
* 2. Indicating top right
* 3. Indicating bottom left
* 4. Indicating bottom right (default)
* - Successful result {"d":"wmt2b2a6c0"}
* - Failure Result: {"d":"ERROR: Error creating Watermarker Pro Token"}
* {"Username":"test2@dmca.com","Password":"test","Root":"http://www.testsite.com/root","Text":"This is the test copyright text","BarOpacity":"50","LogoOpacity":"50","Position":"4","LogoUrl":"http://somesite.com/mylogo.jpg"
* @since      2012-04-08
*/
function CreateWaterMarkerProToken($Username, $Password, $Root, $Text, $BarOpacity, $LogoOpacity, $Position, $LogoUrl) {
	$url = DMCA_RESTFULL_API_URL . 'CreateWaterMarkerProToken';
	$response = wp_remote_request( $url, array(
		'timeout' 		=> '30',
		'redirection' 	=> '5',
		'method' => 'POST',
		'body' =>  '{"Username":"' . $Username . '", "Password":"' . $Password . '", "Root":"' . $Root . '", "Text":"' . $Text . '", "BarOpacity":"' .$BarOpacity . '", "LogoOpacity":"' . $LogoOpacity . '", "Position":"' . $Position . '","LogoUrl":"' . $LogoUrl . '"}',
		'headers' => array('content-type' => 'application/json; charset=utf-8'),
		'blocking'		=> true,
		'compress'		=> false,
		'decompress'	=> true,
		'sslverify' => false,
	));
	
	if( wp_remote_retrieve_response_code( $response ) == 200 ){
		$body = wp_remote_retrieve_body( $response );
		if( $body == '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">Login failed</string>' ){
			return false;
		}
		return html_entity_decode( $body );
	} else{
		return false;
	}
}

/**
* GetWaterMarkerToken
* Creates and returns a WaterMarker token.
* Syntax public string 
* GetWaterMarkerToken (string Email , string Password , string WaterMarkerTokenId )
* Parameters
* Email type: string 
* Password type: string 
* WaterMarkerTokenId type: string
* Return Value
* Type: string
* Remarks
* - Requires JSON formatted Request Body
* - Requests should be made with the following request headers - Content-type: application/json; charset=utf-8
* - Requires a valid email address.
* - HTTPS is required for this operation
* HTTP Method: POST
* Example:
* - URL: https://www.dmca.com/rest/GetWaterMarkerToken
* - Request Headers: Content-type: application/json; charset=utf-8
* - Request Body:
* - Successful result {"d":"{\"DOMAIN\":\"www.testsite.com\",\"SERVICE_LEVEL\":1,\"TITLE\":null,\"HIDDEN_FOLDER\":\"http:\/\/www.testsite.com\/root\",\"LIMIT_REFERERS\":false,\"DATE_ENTERED\":\"\\\/Date(1332288646995)\\\/\",\"WATERMARK_TEXT\":\"This is the test copyright text\",\"WATERMARK_IMAGE\":null,\"POSITIION\":0,\"AUTH_STRING\":\"78e6b9b565204dcf94943954c798a135\",\"APPEND_MODE\":null,\"LOGO_OPACITY\":\"100\",\"BAR_OPACITY\":\"100\",\"Timestamp\":\"\\\/Date(1332288643427)\\\/\",\"AccountId\":\"bfb8a6b0-425f-44ca-8338-07ccdaaa6dc9\",\"TokenId\":\"wmt2b2a6c0\"}"}
* - Failure Result: {"d":"ERROR: Error getting Watermarker Token"}
* @since      2012-04-08
*/
function GetWaterMarkerToken($Username, $Password, $WaterMarkerTokenId) {
	$url = DMCA_RESTFULL_API_URL . 'GetWaterMarkerToken';
	$response = wp_remote_request( $url, array(
		'timeout' 		=> '30',
		'redirection' 	=> '5',
		'method' => 'POST',
		'body' =>  '{"Username":"' . $Username . '", "Password":"' . $Password . '", "WaterMarkerTokenId":"' . $WaterMarkerTokenId . '"}',
		'headers' => array('content-type' => 'application/json; charset=utf-8'),
		'blocking'		=> true,
		'compress'		=> false,
		'decompress'	=> true,
		'sslverify' => false,
	));
	
	if( wp_remote_retrieve_response_code( $response ) == 200 ){
		$body = wp_remote_retrieve_body( $response );
		if( $body == '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">Login failed</string>' ){
			return false;
		}
		return html_entity_decode( $body );
	} else{
		return false;
	}
}

/**
* DeleteWaterMarkerToken
* Deletes a WaterMarker token
* Syntax public string 
* DeleteWaterMarkerToken (string Email , string Password , string WaterMarkerTokenId )
* Parameters
* Email type: string 
* Password type: string 
* WaterMarkerTokenId type: string
* {"Username":"test2@dmca.com","Password":"test","WaterMarkerTokenId":"wmt2b2a6c0"}
* Return Value
* Type: string
* Remarks
* - Requires JSON formatted Request Body
* - Requests should be made with the following request headers - Content-type: application/json; charset=utf-8
* - Requires a valid email address.
* - HTTPS is required for this operation
* HTTP Method: POST
* Example:
* - URL: https://www.dmca.com/rest/DeleteWaterMarkerToken
* - Request Headers: Content-type: application/json; charset=utf-8
* - Request Body:
* - Successful result {"d":"SUCCESS: Token Deleted wmt2b2a6c0"}
* - Failure Result: {"d":"ERROR: Error creating Watermarker Token"}
* @since      2012-04-08
*/
function DeleteWaterMarkerToken($Username, $Password, $WaterMarkerTokenId) {
	$url = DMCA_RESTFULL_API_URL . 'DeleteWaterMarkerToken';
	$response = wp_remote_request( $url, array(
		'timeout' 		=> '30',
		'redirection' 	=> '5',
		'method' => 'POST',
		'body' =>  '{"Username":"' . $Username . '", "Password":"' . $Password . '", "WaterMarkerTokenId":"' . $WaterMarkerTokenId . '"}',
		'headers' => array('content-type' => 'application/json; charset=utf-8'),
		'blocking'		=> true,
		'compress'		=> false,
		'decompress'	=> true,
		'sslverify' => false,
	));
	
	if( wp_remote_retrieve_response_code( $response ) == 200 ){
		$body = wp_remote_retrieve_body( $response );
		if( $body == '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">Login failed</string>' ){
			return false;
		}
		return html_entity_decode( $body );
	} else{
		return false;
	}
}

/**
* UpdateWaterMarkerToken
* Updates an existing WaterMarker token
* Syntax public string 
* UpdateWaterMarkerToken (string Email , string Password , string WaterMarkerTokenId , string Root , string Text )
* Parameters
* Email type: string 
* Password type: string 
* WaterMarkerTokenId type: string 
* Root type: string 
* Text type: string
* Return Value
* Type: string
* Remarks
* - Requires JSON formatted Request Body
* - Requests should be made with the following request headers - Content-type: application/json; charset=utf-8
* - Requires a valid email address.
* - HTTPS is required for this operation
* HTTP Method: POST
* Example:
* - URL: https://www.dmca.com/rest/UpdateWaterMarkerToken
* {"Username":"test2@dmca.com","Password":"test","WaterMarkerTokenId":"wmt2b2a6c0"}
* - Request Headers: Content-type: application/json; charset=utf-8
* - Request Body:
* - BarOpacity must be a number between 0 and 100 (100 default)
* - LogoOpacity must be a number between 0 and 100 (100 default)
* - Position must be a number between 1 and 4.
* 1. Indicating top left
* 2. Indicating top right
* 3. Indicating bottom left
* 4. Indicating bottom right (default)
* - Successful result {"d":"SUCCESS: Token Updated wmt2b2a6c0"}
* - Failure Result: {"d":"ERROR: Error updating Watermarker Token"}
* @since      2012-04-08
*/
function UpdateWaterMarkerToken($Username, $Password, $WaterMarkerTokenId, $Root, $Text, $BarOpacity, $LogoOpacity, $Position) {
	$url = DMCA_RESTFULL_API_URL . 'UpdateWaterMarkerToken';
	$response = wp_remote_request( $url, array(
		'timeout' 		=> '30',
		'redirection' 	=> '5',
		'method' => 'POST',
		'body' =>  '{"Username":"' . $Username . '", "Password":"' . $Password . '", "WaterMarkerTokenId":"' . $WaterMarkerTokenId . '", "Root":"' . $Root . '", "Text":"' . $Text . '","BarOpacity":"' .$BarOpacity . '", "LogoOpacity":"' . $LogoOpacity . '", "Position":"' . $Position . '"}',
		'headers' => array('content-type' => 'application/json; charset=utf-8'),
		'blocking'		=> true,
		'compress'		=> false,
		'decompress'	=> true,
		'sslverify' => false,
	));
	
	if( wp_remote_retrieve_response_code( $response ) == 200 ){
		$body = wp_remote_retrieve_body( $response );
		if( $body == '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">Login failed</string>' ){
			return false;
		}
		return html_entity_decode( $body );
	} else{
		return false;
	}
}

/**
* UpdateWaterMarkerProToken
* Updates an existing WaterMarker Pro token
* Syntax public string 
* UpdateWaterMarkerProToken (string Email , string Password , string WaterMarkerTokenId , string Root , string Text , int BarOpacity , int LogoOpacity , int Position , string LogoUrl )
* Parameters
* Email type: string 
* Password type: string 
* WaterMarkerTokenId type: string 
* Root type: string 
* Text type: string 
* BarOpacity type: int (between 0 and 100) 
* LogoOpacity type: int (between 0 and 100) 
* Position type: int (between 1 and 4) 
* LogoUrl type: string
* Return Value
* Type: string
* Remarks
* - Requires JSON formatted Request Body
* - Requests should be made with the following request headers - Content-type: application/json; charset=utf-8
* - Requires a valid email address.
* - HTTPS is required for this operation
* HTTP Method: POST
* Example:
* - URL: https://www.dmca.com/rest/UpdateWaterMarkerProToken
* - Request Headers: Content-type: application/json; charset=utf-8
* {"Username":"test2@dmca.com","Password":"test","WaterMarkerTokenId":"wmt2b2a6c0","Root":"http://www.testsite.com/root","Text":"This is the test copyright text"}
* - Request Body:
* - BarOpacity must be a number between 0 and 100 (100 default)
* - LogoOpacity must be a number between 0 and 100 (100 default)
* - Position must be a number between 1 and 4.
* 1. Indicating top left
* 2. Indicating top right
* 3. Indicating bottom left
* 4. Indicating bottom right (default)
* - Successful result {"d":"SUCCESS: Token Updated wmt2b2a6c0"}
* - Failure Result: {"d":"ERROR: Error updating Watermarker Token"}
* @since      2012-04-08
*/
function UpdateWaterMarkerProToken($Username, $Password, $WaterMarkerTokenId, $Root, $Text, $BarOpacity, $LogoOpacity, $Position, $LogoUrl) {
	$url = DMCA_RESTFULL_API_URL . 'UpdateWaterMarkerProToken';
	$response = wp_remote_request( $url, array(
		'timeout' 		=> '30',
		'redirection' 	=> '5',
		'method' => 'POST',
		'body' =>  '{"Username":"' . $Username . '", "Password":"' . $Password . '", "WaterMarkerTokenId":"' . $WaterMarkerTokenId . '", "Root":"' . $Root . '", "Text":"' . $Text . '","BarOpacity":"' .$BarOpacity . '", "LogoOpacity":"' . $LogoOpacity . '", "Position":"' . $Position . '", "LogoUrl":"' . $LogoUrl . '"}',
		'headers' => array('content-type' => 'application/json; charset=utf-8'),
		'blocking'		=> true,
		'compress'		=> false,
		'decompress'	=> true,
		'sslverify' => false,
	));
	
	if( wp_remote_retrieve_response_code( $response ) == 200 ){
		$body = wp_remote_retrieve_body( $response );
		if( $body == '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">Login failed</string>' ){
			return false;
		}
		return html_entity_decode( $body );
	} else{
		return false;
	}
}

/**
* ResetWaterMarkerToken
* Resets a WaterMarker tokens imagen but keeps token in tact
* Syntax public string 
* ResetWaterMarkerToken (string Email , string Password , string WaterMarkerTokenId )
* Parameters
* Email type: string 
* Password type: string 
* WaterMarkerTokenId type: string
* Return Value
* Type: string
* Remarks
* - Requires JSON formatted Request Body
* - Requests should be made with the following request headers - Content-type: application/json; charset=utf-8
* - Requires a valid email address.
* - HTTPS is required for this operation
* HTTP Method: POST
* Example:
* - URL: https://www.dmca.com/rest/ResetWaterMarkerToken
* - Request Headers: Content-type: application/json; charset=utf-8
* - Request Body:
* - Successful result {"d":"SUCCESS: Token reset wmt2b2a6c0"}
* - Failure Result: {"d":"ERROR: Token not reset"}
* {"Username":"test2@dmca.com","Password":"test","WaterMarkerTokenId":"wmt2b2a6c0","Root":"http://www.testsite.com/root","Text":"This is the test copyright text","BarOpacity":"50","LogoOpacity":"50","Position":"4","LogoUrl":"http://somesite.com/mylogo.jpg"}
* {"Username":"test2@dmca.com","Password":"test","WaterMarkerTokenId":"wmt2b2a6c0"}
* @since      2012-04-08
*/
function ResetWaterMarkerToken($Username, $Password, $WaterMarkerTokenId) {
	$url = DMCA_RESTFULL_API_URL . 'ResetWaterMarkerToken';
	$response = wp_remote_request( $url, array(
		'timeout' 		=> '30',
		'redirection' 	=> '5',
		'method' => 'POST',
		'body' =>  '{"Username":"' . $Username . '", "Password":"' . $Password . '", "WaterMarkerTokenId":"' . $WaterMarkerTokenId . '"}',
		'headers' => array('content-type' => 'application/json; charset=utf-8'),
		'blocking'		=> true,
		'compress'		=> false,
		'decompress'	=> true,
		'sslverify' => false,
	));
	
	if( wp_remote_retrieve_response_code( $response ) == 200 ){
		$body = wp_remote_retrieve_body( $response );
		if( $body == '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">Login failed</string>' ){
			return false;
		}
		return html_entity_decode( $body );
	} else{
		return false;
	}
}

/**
* GetWaterMarkerTokens
* Returns a list of WaterMarker tokens
* Syntax public string 
* GetWaterMarkerTokens (string Email , string Password )
* Parameters
* Email type: string 
* Password type: string
* Return Value
* Type: string
* Remarks
* - Requires JSON formatted Request Body
* - Requests should be made with the following request headers - Content-type: application/json; charset=utf-8
* - Requires a valid email address.
* - HTTPS is required for this operation
* HTTP Method: POST
* Example:
* - URL: https://www.dmca.com/rest/GetWaterMarkerTokens
* - Request Headers: Content-type: application/json; charset=utf-8
* - Request Body:
* - Failure Result: {"d":" ERROR: Error getting Watermarker Tokens "}
* {"Username":"test2@dmca.com","Password":"test"}
* {"d":"{\"DOMAIN\":\"www.testsite.com\",\"SERVICE_LEVEL\":1,\"TITLE\":null,\"HIDDEN_FOLDER\":\"http:\/\/www.testsite.com\/root\",\"LIMIT_REFERERS\":false,\"DATE_ENTERED\":\"\\\/Date(1333923492645)\\\/\",\"WATERMARK_TEXT\":\"This is the test copyright text\",\"WATERMARK_IMAGE\":null,\"POSITIION\":0,\"AUTH_STRING\":\"0e0d34526629431fb73999ebedbb5d87\",\"APPEND_MODE\":null,\"LOGO_OPACITY\":\"50\",\"BAR_OPACITY\":\"50\",\"Timestamp\":\"\\\/Date(1333923492158)\\\/\",\"AccountId\":\"bfb8a6b0-425f-44ca-8338-07ccdaaa6dc9\",\"TokenId\":\"wmtf26b1ca\"}"}
* @since      2012-04-08
*/
function GetWaterMarkerTokens($Username, $Password) {
	$url = DMCA_RESTFULL_API_URL . 'GetWaterMarkerTokens';
	$response = wp_remote_request( $url, array(
		'timeout' 		=> '30',
		'redirection' 	=> '5',
		'method' => 'POST',
		'body' =>  '{"Username":"' . $Username . '", "Password":"' . $Password . '"}',
		'headers' => array('content-type' => 'application/json; charset=utf-8'),
		'blocking'		=> true,
		'compress'		=> false,
		'decompress'	=> true,
		'sslverify' => false,
	));
	
	if( wp_remote_retrieve_response_code( $response ) == 200 ){
		$body = wp_remote_retrieve_body( $response );
		if( $body == '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">Login failed</string>' ){
			return false;
		}
		return html_entity_decode( $body );
	} else{
		return false;
	}
}

?>