<?php
/*
Plugin Name: DMCA WaterMarker
Description: Protect your images with a DMCA.com WaterMarker.
Version: 1.1
Author: DMCA.com
Author URI: http://wordpress.org/extend/plugins/dmca-wm/   
Plugin URI: http://dmca.com
*/

require_once('dmca-restful.php');

register_activation_hook(__FILE__, array('DMCA_WM', 'activation'));
register_deactivation_hook(__FILE__, array('DMCA_WM', 'deactivation'));

DMCA_WM::init();
/**
 * DMCA_WM
 *
 * DONE
 * =====
 * - Enable DMCA WaterMarking for a specific folder using the form
 * - Use that URL to reference your image (e.g. http://wms.dmca.com/wmt532342/myimage.jpg)
 * - Change the Image links on your entire site to point to the new folder (your masked URL).
 *
 *
 * @since      2012-03-31
 */

class DMCA_WM {
    const version         = '0.1';
	const domain          = 'dmca_wm';
    const settings_account_key = 'dmca_wm_account';
    const settings_configuration_key = 'dmca_wm_configuration';
    const settings_status_key = 'dmca_wm_status';

	static $url           = 'https://www.dmca.com/rest';
    static $masked_domain = 'http://wms.dmca.com/';

	static $settings_page = null;
	static $pluginUrl = '';
    static $settings_tabs = array();

	/**
	 * Hook into WordPress.
	 *
	 * @since      2012-03-31
	 */
	static function init() {
		self::$pluginUrl	= WP_PLUGIN_URL . '/' . basename(dirname(__FILE__));

		/* Admin Hooks. */
		add_action( 'plugins_loaded',       array( __CLASS__, 'load_textdomain' ) );
		add_action( 'admin_menu',           array( __CLASS__, 'settings_menu' ),    10 );
		add_action( 'admin_menu',           array( __CLASS__, 'settings_enqueue' ), 11 );
        add_action( 'admin_init',           array( __CLASS__, 'register_settings_account' ) );
        add_action( 'admin_init',           array( __CLASS__, 'register_settings_configuration' ) );
        add_action( 'admin_init',           array( __CLASS__, 'register_settings_status' ) );

        add_filter( 'plugin_action_links',  array( __CLASS__, 'add_settings_link' ), 10, 2 );

		/* Public Hooks. */
		if (self::get_setting( self::settings_status_key, 'token')) {
			add_filter('the_content', array( __CLASS__, 'watermarking_content' ));		
		}
	}

    /**
     * Plugin Activation.
     *
     * @since      2012-04-16
     */
    function activation(){
        add_option(self::settings_account_key);
        add_option(self::settings_configuration_key);
        add_option(self::settings_status_key);
    }

    /**
	 * Plugin Deactivation.
	 *
	 * @since      2012-04-13
	 */
	function deactivation(){
		delete_option(self::settings_account_key);
        delete_option(self::settings_configuration_key);
        delete_option(self::settings_status_key);
	}
	
    /**
	 * WaterMarking Content.
	 *
	 * @since      2012-04-01
	 */
    static function watermarking_content( $content ){
		$protected_url = self::get_setting( self::settings_configuration_key, 'website_url');
        $token = self::get_setting( self::settings_status_key, 'token');
        $masked_url = self::$masked_domain . $token;
		$pattern = '#(' . $protected_url . '[A-Za-z0-9-_:%&~\?\/.=]+)#si';
		preg_match_all($pattern, $content, $matches);
		if (count($matches[0]) > 0) {
			$image_sizes = self::get_setting(self::settings_configuration_key, 'image_sizes');
			if (in_array('all', $image_sizes)) {
				$content = str_replace($protected_url, $masked_url, $content);
			} else {
				if (in_array('full', $image_sizes)) {
					$pattern = '#[0-9]{3}x[0-9]{3}#si';
					foreach ($matches[0] as $key => $url) {
						preg_match_all($pattern, $url, $m);
						if (count($m[0]) == 0) {
							$new_url = str_replace($protected_url, $masked_url, $url);
							$content = str_replace($url, $new_url, $content);
							unset($matches[0][$key]); 
						}
					}
					unset($image_sizes['full']); 
				}
				foreach ($image_sizes as $image_size) {
					$size = DMCA_WM::get_image_size($image_size);
					$findme   = $size['width'] . 'x';
					foreach ($matches[0] as $key => $url) {
						$pos = strpos($url, $findme);
						if ($pos !== false) {
							$new_url = str_replace($protected_url, $masked_url, $url);
							$content = str_replace($url, $new_url, $content);
							unset($matches[0][$key]); 
						}				
					}
				}
			}
		}
        return $content;
    }
	
    /**
	 * Add settings link to plugin listing on plugins page.
	 *
	 * @since      2012-03-31
	 */
    static function add_settings_link( $links, $file ){
        if( $file == plugin_basename(__FILE__) ){
            $settings_link = '<a href="'.admin_url('options-general.php?page=dmca_wm').'">'.__('Settings', self::domain).'</a>';
            array_unshift($links, $settings_link);
        }
        return $links;
    }

	/**
	 * Load Text Domain.
	 *
	 * @since      2012-03-31
	 */
	static function load_textdomain() {
		load_plugin_textdomain( self::domain, false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	}

	/**
	 * Dynamic hooks for Settings page.
	 *
	 * @since      2012-03-31
	 */
	static function settings_enqueue() {
		add_action( 'admin_print_styles-' . self::$settings_page, array( __CLASS__, 'style_settings_page' ) );
	}

	/**
	 * Settings Page Styles.
	 *
	 * @since      2012-03-31
	 */
	static function style_settings_page() {
		wp_enqueue_style(
			self::domain . '_settings',
			plugin_dir_url( __FILE__ ) . 'style-settings-page.css',
			array(),
			self::version,
			'screen'
		);
	}
	
	/**
	 * Add Link to Admin Menu.
	 *
	 * @since      2012-03-31
	 */
	static function settings_menu() {
		self::$settings_page = add_options_page(
			__( 'DMCA WaterMarker', self::domain ),
			__( 'DMCA WaterMarker', self::domain ),
			'manage_options',
			self::domain,
			array( __CLASS__, 'settings_page' )
			);
	}

	/**
	 * Register Account Settings.
	 *
	 * @since      2012-04-15
	 */
    static function register_settings_account() {
        self::$settings_tabs[self::settings_account_key] = 'Account';
        register_setting(
            self::settings_account_key,
            self::settings_account_key,
            array( __CLASS__, 'settings_sanitize_account' )
        );

        if ((self::get_setting(self::settings_account_key, 'action') != 'create-account') && (self::get_setting(self::settings_account_key, 'action') != 'login-account') && (self::get_setting(self::settings_account_key, 'status') != 'logged')) {
            add_settings_section(
                self::settings_account_key . '_readme',
                __( '', self::domain ),
                array( __CLASS__, 'message_readme' ),
                self::settings_account_key
            );
            add_settings_section(
                self::settings_account_key . '_readme_begin',
                __( '', self::domain ),
                array( __CLASS__, 'message_readme_begin' ),
                self::settings_account_key
            );
            add_settings_section(
                self::settings_account_key . '_free_account',
                __( 'New Account', self::domain ),
                array( __CLASS__, 'message_free_account' ),
                self::settings_account_key
            );
            add_settings_field(
                self::settings_account_key . '_free_first_name',
                __( 'First Name:', self::domain ),
                array( __CLASS__, 'control_free_first_name' ),
                self::settings_account_key,
                self::settings_account_key . '_free_account'
            );
            add_settings_field(
                self::settings_account_key . '_free_last_name',
                __( 'Last Name:', self::domain ),
                array( __CLASS__, 'control_free_last_name' ),
                self::settings_account_key,
                self::settings_account_key . '_free_account'
            );
            add_settings_field(
                self::settings_account_key . '_free_company_name',
                __( 'Company:', self::domain ),
                array( __CLASS__, 'control_free_company_name' ),
                self::settings_account_key,
                self::settings_account_key . '_free_account'
            );
            add_settings_field(
                self::settings_account_key . '_free_email',
                __( 'Email:', self::domain ),
                array( __CLASS__, 'control_free_email' ),
                self::settings_account_key,
                self::settings_account_key . '_free_account'
            );
            add_settings_field(
                self::settings_account_key . '_create_account',
                __( '', self::domain ),
                array( __CLASS__, 'control_create_account' ),
                self::settings_account_key,
                self::settings_account_key . '_free_account'
            );
            add_settings_field(
                self::settings_account_key . '_fetch_pro',
                false,
                array( __CLASS__, 'submit_create_account' ),
                self::settings_account_key,
                self::settings_account_key . '_free_account'
            );
            add_settings_section(
                self::settings_account_key . '_readme_end',
                __( '', self::domain ),
                array( __CLASS__, 'message_readme_end' ),
                self::settings_account_key
            );
        }
        add_settings_section(
            self::settings_account_key . '_pro_account_begin',
            __( '', self::domain ),
            array( __CLASS__, 'message_pro_account_begin' ),
            self::settings_account_key
        );
        add_settings_section(
            self::settings_account_key . '_pro_account',
            __( 'Existing Account', self::domain ),
            array( __CLASS__, 'message_pro_account' ),
            self::settings_account_key
        );
        add_settings_field(
            self::settings_account_key . '_pro_username',
            __( 'Email:', self::domain ),
            array( __CLASS__, 'control_pro_username' ),
            self::settings_account_key,
            self::settings_account_key . '_pro_account'
        );
        add_settings_field(
            self::settings_account_key . '_pro_password',
            __( 'Password:', self::domain ),
            array( __CLASS__, 'control_pro_password' ),
            self::settings_account_key,
            self::settings_account_key . '_pro_account'
        );
        add_settings_field(
            self::settings_account_key . '_fetch_pro',
            false,
            array( __CLASS__, 'control_fetch_pro' ),
            self::settings_account_key,
            self::settings_account_key . '_pro_account'
        );
        add_settings_section(
            self::settings_account_key . '_pro_account_end',
            __( '', self::domain ),
            array( __CLASS__, 'message_pro_account_end' ),
            self::settings_account_key
        );
    }

    /**
     * Register Configuration Settings.
     *
     * @since      2012-04-15
     */
    static function register_settings_configuration() {
        self::$settings_tabs[self::settings_configuration_key] = 'Configuration';
        register_setting(
            self::settings_configuration_key,
            self::settings_configuration_key,
            array( __CLASS__, 'settings_sanitize_configuration' )
        );
        add_settings_section(
            self::settings_configuration_key . '_watermarker',
            __( '', self::domain ),
            array( __CLASS__, 'message_watermarker' ),
            self::settings_configuration_key
        );
        add_settings_field(
            self::settings_configuration_key . '_watermark_auto',
            __( 'Copyright Owner: ', self::domain ),
            array( __CLASS__, 'control_watermark_auto' ),
            self::settings_configuration_key,
            self::settings_configuration_key . '_watermarker'
        );
        add_settings_field(
            self::settings_configuration_key . '_position',
            __( 'Position: ', self::domain ),
            array( __CLASS__, 'control_position' ),
            self::settings_configuration_key,
            self::settings_configuration_key . '_watermarker'
        );
        add_settings_field(
            self::settings_configuration_key . '_website_url',
            __( 'Media Upload URL: ', self::domain ),
            array( __CLASS__, 'control_website_url' ),
            self::settings_configuration_key,
            self::settings_configuration_key . '_watermarker'
        );
        add_settings_field(
            self::settings_configuration_key . '_image_sizes',
            __( 'Show WaterMarks for Image Sizes', self::domain ),
            array( __CLASS__, 'control_image_sizes' ),
            self::settings_configuration_key,
            self::settings_configuration_key . '_watermarker'
        );
        add_settings_field(
            self::settings_configuration_key . '_submit_configuration',
            false,
            array( __CLASS__, 'submit_configuration' ),
            self::settings_configuration_key,
            self::settings_configuration_key . '_watermarker'
        );
    }

    /**
     * Register Status Settings.
     *
     * @since      2012-04-15
     */
    static function register_settings_status() {
        if( self::get_setting(self::settings_status_key, 'token') ){
            $status = '&nbsp;<span style="color:green;">' . __('protected.', self::domain ) . '</span>';
        } else {
            $status = '&nbsp;<span style="color:red;">' . __('unprotected.', self::domain ) . '</span>';
        }
        self::$settings_tabs[self::settings_status_key] = 'Status' . $status;

        register_setting(
            self::settings_status_key,
            self::settings_status_key,
            array( __CLASS__, 'settings_sanitize_status' )
        );

        add_settings_section(
            self::settings_status_key . '_status',
            __( '', self::domain ),
            array( __CLASS__, 'message_status' ),
            self::settings_status_key
        );
        add_settings_field(
            self::settings_status_key . '_change_status',
            __( '', self::domain ),
            array( __CLASS__, 'control_change_status' ),
            self::settings_status_key,
            self::settings_status_key . '_status'
        );
    }


    /**
	 * Message for Pro Account section of settings page.
	 *
	 * @since      2012-03-31
	 */
	static function message_readme() {
        echo '<p>';
        esc_html_e( 'To protect your images you need a DMCA.com account. You can create a FREE DMCA.com WaterMarking account or login with your existing account.', self::domain );
        echo '</p>';
	}

    static function message_readme_begin() {
        echo '<div style="float:left;border-right:solid 1px;width:500px;margin-right:20px;">';
    }

    static function message_readme_end() {
        echo '</div>';
    }

	/**
	 * Message forFree Account section of settings page.
	 *
	 * @since      2012-04-15
	 */
	static function message_free_account() {
	}

    /**
     * Begin for Pro Account section of settings page.
     *
     * @since      2012-04-15
     */
    static function message_pro_account_begin() {
        echo '<div style="float:left;">';
    }

    static function message_pro_account_end() {
        echo '</div>';
    }

	/**
	 * Message for Pro Account section of settings page.
	 *
	 * @since      2012-04-15
	 */
	static function message_pro_account() {
        if (self::get_setting(self::settings_account_key, 'action') == 'create-account') {
            $key = 'create_account';
            $id = self::settings_account_key . '_' . $key;
            echo '<div id="' . $id . '_wrap">';
            if( self::get_setting(self::settings_account_key, 'free_first_name') && self::get_setting(self::settings_account_key, 'free_last_name') && self::get_setting(self::settings_account_key, 'free_email')   ){
                $result = RegisterNewAccount(self::get_setting(self::settings_account_key, 'free_first_name'), self::get_setting(self::settings_account_key, 'free_last_name'), self::get_setting(self::settings_account_key, 'free_company_name'), self::get_setting(self::settings_account_key, 'free_email'));
                if( $result ){
                    echo '<p style="color:green;">' . __('New Account Created. Check Your Email For Confirmation.', self::domain ) . '</p>';

                } else{
                    echo '<p style="color:red;">' . __('There was a problem creating your account. Please try again.', self::domain ) . '</p>';
                }
            }
            echo '</div>';
            self::set_setting(self::settings_account_key, 'action', '');
        }
        if (self::get_setting(self::settings_account_key, 'action') == 'login-account') {
            $key = 'login_account';
            $id = self::settings_account_key . '_' . $key;
            echo '<div id="' . $id . '_wrap">';
            if( self::get_setting(self::settings_account_key, 'pro_username') && self::get_setting(self::settings_account_key, 'pro_password')){
                $result = GetWaterMarkerTokens(self::get_setting(self::settings_account_key, 'pro_username'), self::get_setting(self::settings_account_key, 'pro_password'));
                if( $result ){
                    echo '<p style="color:green;">' . __('The Account Logged.', self::domain ) . '</p>';
                    $_POST['status'] = 'logged';
                    self::set_setting(self::settings_status_key, 'status',  'logged');
                } else{
                    echo '<p style="color:red;">' . __('There was a problem logging your account. Please try again.', self::domain ) . '</p>';
                }
            }
            echo '</div>';
            self::set_setting(self::settings_account_key, 'action', '');
        }
        if (self::get_setting(self::settings_account_key, 'action') == 'logout-account') {
            $key = 'logout_account';
            $id = self::settings_account_key . '_' . $key;
            echo '<div id="' . $id . '_wrap">';
            echo '<p style="color:green;">' . __('The Account Logouted.', self::domain ) . '</p>';
            echo '</div>';
            $_POST['status'] = '';
            self::set_setting(self::settings_status_key, 'status',  '');
            self::set_setting(self::settings_account_key, 'action', '');
        }

	}
	
    /**
	 * Message for WaterMarker section of settings page.
	 *
	 * @since      2012-04-15
	 */
	static function message_watermarker() {
	}

	/**
	 * Message for Theme Integration section of settings page.
	 *
	 * @since      2012-03-31
	 */
	static function message_theme_integration() {
		print sprintf( esc_html__( 'The following settings enable you to automatically add DMCA WaterMarking at different places in your theme.', self::domain ));
	}

    /**
     * Message for Theme Integration section of settings page.
     *
     * @since      2012-03-31
     */
    static function message_status() {
        if (self::get_setting(self::settings_status_key, 'action') == 'activate-protection') {
            $key = 'activate_protection';
            $id = self::settings_status_key . '_' . $key;
            echo '<div id="' . $id . '_wrap">';
            if( self::get_setting(self::settings_account_key, 'pro_username') && self::get_setting(self::settings_account_key, 'pro_password') && self::get_setting(self::settings_configuration_key, 'website_url')){
                $result = CreateWaterMarkerToken(self::get_setting(self::settings_account_key, 'pro_username'), self::get_setting(self::settings_account_key, 'pro_password'), self::get_setting(self::settings_configuration_key, 'website_url'), self::get_setting(self::settings_configuration_key, 'watermark_auto'));
                if( $result ){
                    $obj = json_decode($result);
                    if (!empty($obj->d)) {
                        $_POST['token'] =  $obj->d;
                        $_POST['action'] = "";
                        self::set_setting(self::settings_status_key, 'token',  $obj->d);
                        UpdateWaterMarkerToken(self::get_setting(self::settings_account_key, 'pro_username'), self::get_setting(self::settings_account_key, 'pro_password'), $obj->d, self::get_setting(self::settings_configuration_key, 'website_url'), self::get_setting(self::settings_configuration_key, 'watermark_auto'), 100, 100, self::get_setting(self::settings_configuration_key, 'position'));
                        ResetWaterMarkerToken(self::get_setting(self::settings_account_key, 'pro_username'), self::get_setting(self::settings_account_key, 'pro_password'), $obj->d);
                        echo '<p style="color:green;">' . __('The Protection Activated.', self::domain ) . '</p>';
                    } else {
                        echo '<p style="color:red;">' . __('There was a problem activating your protection. Please try again.', self::domain ) . '</p>';
                    }
                } else{
                    echo '<p style="color:red;">' . __('There was a problem activating your protection. Please try again.', self::domain ) . '</p>';
                }
            }
            echo '</div>';
            self::set_setting(self::settings_status_key, 'action', '');
        }
        if (self::get_setting(self::settings_status_key, 'action') == 'deactivate-protection') {
            $key = 'deactivate_protection';
            $id = self::settings_status_key . '_' . $key;
            echo '<div id="' . $id . '_wrap">';
            if( self::get_setting(self::settings_account_key, 'pro_username') && self::get_setting(self::settings_account_key, 'pro_password') && self::get_setting(self::settings_configuration_key, 'website_url')){
                $result = DeleteWaterMarkerToken(self::get_setting(self::settings_account_key, 'pro_username'), self::get_setting(self::settings_account_key, 'pro_password'), self::get_setting(self::settings_status_key, 'token'));
                if( $result ){
                    echo '<p style="color:green;">' . __('The Protection Deactivated.', self::domain ) . '</p>';
                    $_POST['token'] = "";
                    $_POST['action'] = "";
                    self::set_setting(self::settings_status_key, 'token', '');
                } else{
                    echo '<p style="color:red;">' . __('There was a problem deactivating your protection. Please try again.', self::domain ) . '</p>';
                }
            }
            echo '</div>';
            self::set_setting(self::settings_status_key, 'action', '');
        }
    }

	/**
	 * Settings Page Template.
	 *
	 * @since      2012-03-31
	 */
	static function settings_page() {
		print "\n" . '<div class="wrap" id="' . esc_attr( self::$settings_page ) . '">';
		screen_icon('dmca');
		print "\n" . '<h2 style="padding: 40px;">' . esc_html__( 'WaterMarker protect your photos', self::domain ) . '</h2>';
		
    $tab = isset( $_GET['tab'] ) ? $_GET['tab'] : self::settings_account_key;
            self::settings_tabs();
	  print "\n" . '<form action="options.php" method="post">';
		settings_fields( $tab );
		do_settings_sections( $tab );
		print "\n" . '</form>';
    print "\n" . '</div>';
	}

    /**
    * Settings Tabs UI
    *
    * @since      2012-04-15
    */
    static function settings_tabs() {
        $current_tab = isset( $_GET['tab'] ) ? $_GET['tab'] : self::settings_account_key;
        echo '<h2 class="nav-tab-wrapper">';
        foreach ( self::$settings_tabs as $tab_key => $tab_caption ) {
            $active = $current_tab == $tab_key ? 'nav-tab-active' : '';
            echo '<a class="nav-tab ' . $active . '" href="?page=' . self::domain  . '&tab=' . $tab_key . '">' . $tab_caption . '</a>';
        }
        echo '</h2>';
    }

    /**
     * Free First Name UI
     *
     * @since      2012-03-31
     */
    static function control_free_first_name(){
        $key = 'free_first_name';
        $id =  self::settings_account_key . '_' . $key;
        $saved = self::get_setting( self::settings_account_key, $key );
        echo '<div id="' . $id . '_wrap">';
        echo '<input type="text" id="' . $id . '" class="' . $id . '" name="' . self::settings_account_key . '[' . $key . ']' . '" value="' . esc_attr('') . '" />';
        echo '</div>';
    }

    /**
     * Free Last Name UI
     *
     * @since      2012-03-31
     */
    static function control_free_last_name(){
        $key = 'free_last_name';
        $id = self::settings_account_key . '_' . $key;
        $saved = self::get_setting( self::settings_account_key, $key );
        echo '<div id="' . $id . '_wrap">';
        echo '<input type="text" id="' . $id . '" class="' . $id . '" name="' . self::settings_account_key . '[' . $key . ']' . '" value="' . esc_attr('') . '" />';
        echo '</div>';
    }

    /**
     * Free Company Name UI
     *
     * @since      2012-03-31
     */
    static function control_free_company_name(){
        $key = 'free_company_name';
        $id = self::settings_account_key . '_' . $key;
        $saved = self::get_setting( self::settings_account_key, $key );
        echo '<div id="' . $id . '_wrap">';
        echo '<input type="text" id="' . $id . '" class="' . $id . '" name="' . self::settings_account_key . '[' . $key . ']' . '" value="' . esc_attr('') . '" />';
        echo '</div>';
    }

    /**
     * Free Email UI
     *
     * @since      2012-03-31
     */
    static function control_free_email(){
        $key = 'free_email';
        $id = self::settings_account_key . '_' . $key;
        $saved = self::get_setting( self::settings_account_key, $key );
        echo '<div id="' . $id . '_wrap">';
        echo '<input type="text" id="' . $id . '" class="' . $id . '" name="' . self::settings_account_key . '[' . $key . ']' . '" value="' . esc_attr('') . '" />';
        echo '</div>';
    }

    /**
     * Free Account UI
     *
     * @since      2012-04-09
     */
    static function control_create_account(){
     }

    /**
     * Submit Create Account UI
     *
     * @since      2012-03-31
     */
    static function submit_create_account(){
        echo '<input type="submit" class="button-primary button-create" name="create-account" value="' . __( 'Create Free WaterMark Account!', self::domain ) . '" />';
    }

    /**
     * Pro Username UI
     *
     * @since      2012-03-31
     */
    static function control_fetch_pro(){
        if (self::get_setting(self::settings_account_key, 'status') == 'logged') {
            echo '<input type="submit" class="button-primary" name="logout-account" value="' . __( 'Logout', self::domain ) . '" />';
        } else {
            echo '<input type="submit" class="button-primary" name="login-account" value="' . __( 'Login', self::domain ) . '" />';
        }
    }

    /**
     * Pro Username UI
     *
     * @since      2012-03-31
     */
    static function control_pro_username(){
        $key = 'pro_username';
        $id = self::settings_account_key . '_' . $key;
        $saved = self::get_setting( self::settings_account_key, $key );
        echo '<div id="' . $id . '_wrap">';
        echo '<input type="text" id="' . $id . '" class="' . $id . '" name="' . self::settings_account_key . '[' . $key . ']' . '" value="' . esc_attr($saved) . '" />';
        echo '</div>';
    }

    /**
     * Pro Password UI
     *
     * @since      2012-03-31
     */
    static function control_pro_password(){
        $key = 'pro_password';
        $id = self::settings_account_key . '_' . $key;
        $saved = self::get_setting( self::settings_account_key, $key );
        echo '<div id="' . $id . '_wrap">';
        echo '<input type="password" id="' . $id . '" class="' . $id . '" name="' . self::settings_account_key . '[' . $key . ']' . '" value="' . esc_attr($saved) . '" />';
        echo '</div>';
    }

    /**
     * Watermark Auto UI
     *
     * @since      2012-04-15
     */
    static function control_watermark_auto(){
        $key = 'watermark_auto';
        $id = self::settings_configuration_key . '_' . $key;
        $saved = self::get_setting( self::settings_configuration_key, $key );
        echo '<div id="' . $id . '_wrap">';
        echo '<input type="text" id="' . $id . '" class="' . $id . '" name="' . self::settings_configuration_key . '[' . $key . ']' . '" value="' . esc_attr($saved) . '" />&nbsp;<span style="font-size: 11px;">(e.g. Acme Company Ltd.)</span>';
        echo '</div>';
    }

    /**
     * Position UI
     *
     * @since      2012-04-17
     */
    static function control_position(){
        $key = 'position';
        $id = self::settings_configuration_key . '_' . $key;
        $saved = self::get_setting( self::settings_configuration_key, $key );
        echo '<div id="' . $id . '_wrap">';
        echo '<select id="' . $id . '" class="' . $id . '" name="' . self::settings_configuration_key . '[' . $key . ']">';
        foreach ( self::get_positions() as $position => $label ) {
            $id = self::settings_configuration_key . '_' . $key . '_' . $position;
            print "\n" . '<option ' . selected( $saved, $position, false ) . ' value="' . esc_attr( $position ) . '" /> ' . esc_html( $label ) . '</option>';
        }
        echo '</select></div>';
    }

    /**
     * Website URL UI
     *
     * @since      2012-04-15
     */
    static function control_website_url(){
        $key = 'website_url';
        $id =  self::settings_configuration_key . '_' . $key;
        $saved = self::get_setting(  self::settings_configuration_key, $key );
        echo '<div id="' . $id . '_wrap">';
        echo '<input type="text" readonly="readonly" size="100" id="' . $id . '" class="' . $id . '" name="' . self::settings_configuration_key . '[' . $key . ']' . '" value="' . esc_attr($saved) . '" />';
        echo '</div>';
    }

    /**
     * Show Watermarks Image Sizes UI.
     *
     * @since      2011-04-15
     */
    static function control_image_sizes() {
        $key = 'image_sizes';
        $saved = self::get_setting( self::settings_configuration_key, $key );
        print '<div id="' . self::settings_configuration_key . '_' . $key . '_wrap" class="' . esc_attr( self::settings_configuration_key . '_multiple_values' ) . '">';
        $id = self::settings_configuration_key . '_' . $key . '_all';
        $checked = ( in_array( 'all', $saved ) ) ? ' checked="checked"' : '';
        print '<p><label for="' . esc_attr( $id ) . '"><input' . $checked . ' id="' . esc_attr( $id ) . '" type="checkbox" name="' . self::settings_configuration_key . '[' . $key .'][]" value="all" onclick="checkAll(this);" />all</label></p>';
        $image_sizes = get_intermediate_image_sizes();
        foreach ( $image_sizes as $k => $s ) {
            $id = self::settings_configuration_key . '_' . $key . '_' . $s;
            $checked = ( in_array( $s, $saved ) ) ? ' checked="checked"' : '';
            print "\n" . '<p><label for="' . esc_attr( $id ) . '"><input' . $checked . ' id="' . esc_attr( $id ) . '" type="checkbox" name="' . self::settings_configuration_key . '[' . $key .'][]" value="' . esc_attr( $s ) . '" /> ' . esc_html( $s ) . '</label></p>';
        }
        $id = self::settings_configuration_key . '_' . $key . '_full';
        $checked = ( in_array( 'full', $saved ) ) ? ' checked="checked"' : '';
        print '<p><label for="' . esc_attr( $id ) . '"><input' . $checked . ' id="' . esc_attr( $id ) . '" type="checkbox" name="' . self::settings_configuration_key . '[' . $key .'][]" value="full" />full</label></p>';
        print '</div>';
        add_action( 'in_admin_footer',  array('DMCA_WM', 'admin_footer'));
    }

    function admin_footer() {
        ?>
    <script type="text/javascript">
        /**
         * Check All Checkboxes
         */
        function checkAll(obj) {
            var checked = null;
            if(jQuery(obj).attr('checked')) {
                checked = true;
            } else {
                checked = false;
            }
            var parent = jQuery(obj).parent().parent().parent();
            jQuery.each(jQuery('input', parent), function() {
                jQuery(this).attr('checked', checked);
            })
        }
    </script>
    <?php
    }

    /**
     * Submit Configuration UI
     *
     * @since      2012-04-15
     */
    static function submit_configuration(){
        echo '<input type="submit" class="button-primary" name="save-configuration" value="' . __( 'Save', self::domain ) . '" />';
    }

    /**
     * Control Change Status UI
     *
     * @since      2012-04-15
     */
    static function control_change_status(){
        if( self::get_setting(self::settings_status_key, 'token') ){
            echo '<input type="submit" class="button-primary button-deactivate" name="deactivate-protection" value="' . __( 'Deactivate Protection', self::domain ) . '" />';
        } else {
            echo '<input type="submit" class="button-primary button-activate" name="activate-protection" value="' . __( 'Activate Protection', self::domain ) . '" />';
        }
    }


    /**
     * Reset Options UI
     *
     * @since      2012-04-01
     */
    static function control_reset_options(){
        echo '<input type="submit" class="button-primary" name="reset-options" value="' . __( 'Reset Options', self::domain ) . '" />';
    }


	public function get_image_size($s) {
		global $_wp_additional_image_sizes;

		if ( isset( $_wp_additional_image_sizes[$s]['width'] ) ) // For theme-added sizes
			$width = intval( $_wp_additional_image_sizes[$s]['width'] );
		else                                                     // For default sizes set in options
			$width = get_option( "{$s}_size_w" );

		if ( isset( $_wp_additional_image_sizes[$s]['height'] ) ) // For theme-added sizes
			$height = intval( $_wp_additional_image_sizes[$s]['height'] );
		else                                                      // For default sizes set in options
			$height = get_option( "{$s}_size_h" );

		if ( isset( $_wp_additional_image_sizes[$s]['crop'] ) )   // For theme-added sizes
			$crop = intval( $_wp_additional_image_sizes[$s]['crop'] );
		else                                                      // For default sizes set in options
			$crop = get_option( "{$s}_crop" );
		$crop = ( $crop == 0 )? 'false' : 'true' ;
		
		return array('image' => $s, 'width' => $width, 'height' =>  $height, 'crop' => $crop);
	}
	
	static function get_image_sizes() {
		$public = array();
		$public['all'] = 'all';
		$public['full'] = 'full';
		$image_sizes = get_intermediate_image_sizes();
		foreach ( (array) $image_sizes as $key => $image_size ) {
			$public[$image_size] = $image_size;
		}
		return $public;
	}

    /**
     * Default Values.
     *
     * @return     array     Default settings.
     *
     * @since      2012-04-15
     */
    static function get_defaults($group) {
        switch ($group) {
            case self::settings_account_key:
                return array();
                break;
            case self::settings_configuration_key:
                $upload_dir = wp_upload_dir();
                return array(
                    'image_sizes' => array(),
                    'website_url' => $upload_dir['baseurl'],
                    'watermark_auto' => get_bloginfo('name'),
                );
                break;
            case self::settings_status_key:
                return array();
                break;
        }
    }

	/**
	 * Get Settings.
	 *
	 * @since      2012-03-31
	 */
	static function get_settings($group) {
		return wp_parse_args( (array) get_option( $group ), self::get_defaults( $group ) );
	}

	/**
	 * Get Setting.
	 *
	 * Gets an individual key stored in the custom settings array.
	 * In the event that an unrecognized key is asked for, boolean
	 * false will be returned.
	 *
	 * @param      string       $key Get a single unsanitized setting.
	 * @return     mixed
	 *
	 * @since      2012-03-31
	 */
	static function get_setting( $group, $key ) {
        $settings = self::get_settings($group);
		if ( isset( $settings[$key] ) ) {
			return $settings[$key];
		}
		return false;
	}

	/**
	 * Set Setting.
	 *
	 * Sets an individual key stored in the custom settings array.
	 * In the event that an unrecognized key is asked for, boolean
	 * false will be returned.
	 *
	 * @param      string       $key Set a single unsanitized setting.
	 * @return     mixed
	 *
	 * @since      2012-03-31
	 */
	static function set_setting( $group, $key, $value ) {
		$settings = self::get_settings($group);
		$settings[$key] = $value;
		update_option( $group,  (array) $settings);
	}

    /**
     * Get Positions.
     *
     * @return     array     List of supported DMCA WaterMaker positions.
     *
     * @since      2012-04-17
     */

    static function get_positions() {
        return array(
            '1'        => __( 'Top Left',   self::domain ),
            '2'   => __( 'Top Right',   self::domain ),
            '3' => __( 'Bottom Left', self::domain ),
            '4'  => __( 'Bottom Right',  self::domain ),
        );
    }

	/**
	 * Sanitize Settings Account.
	 *
	 * @param      array     $dirty List of values that may be settings.
	 * @return     array     Sanitized array of all recognized settings.
	 *
	 * @since      2012-04-15
	 */
	static function settings_sanitize_account($dirty) {

		$clean = array(
			'action'            => '',
            'status'            => '',
			'free_first_name' => '',
			'free_last_name' => '',
			'free_email' => '',
			'free_company_name' => '',
			'pro_username'      => '',
			'pro_password'      => '',
		);

		if (isset($_POST['reset-options'])) {
			return $clean;
		}

		if (isset($_POST['create-account'])) {
			$clean['action'] = 'create-account';
			add_settings_error('', 'account_created', __('Account created.'), 'updated');
		}

        if (isset($_POST['status'])) {
            $clean['status'] = $_POST['status'];
        }

		if( isset( $dirty['free_first_name'] ) ){
			$clean['free_first_name'] = esc_attr( $dirty['free_first_name'] );
		}

		if( isset( $dirty['free_last_name'] ) ){
			$clean['free_last_name'] = esc_attr( $dirty['free_last_name'] );
		}

	   if( isset( $dirty['free_email'] ) ){
			$clean['free_email'] = esc_attr( $dirty['free_email'] );
		}

		if( isset( $dirty['free_company_name'] ) ){
			$clean['free_company_name'] = esc_attr( $dirty['free_company_name'] );
		}

        if (isset($_POST['login-account'])) {
            $clean['action'] = 'login-account';
            $clean['status'] = 'logged';
            add_settings_error('general', 'account_logged', __('Account logged.'), 'updated');
        }

        if (isset($_POST['logout-account'])) {
            $clean['action'] = 'logout-account';
            add_settings_error('general', 'account_logouted', __('Account logouted.'), 'updated');
        }


         if( isset( $dirty['pro_username'] ) ){
			$clean['pro_username'] = esc_attr( $dirty['pro_username'] );
		}

		if( isset( $dirty['pro_password'] ) ){
			$clean['pro_password'] = esc_attr( $dirty['pro_password'] );
		}

		return $clean;
	}

    /**
     * Sanitize Settings Configuration.
     *
     * @param      array     $dirty List of values that may be settings.
     * @return     array     Sanitized array of all recognized settings.
     *
     * @since      2012-04-15
     */
    static function settings_sanitize_configuration($dirty) {
        $upload_dir = wp_upload_dir();

        $clean = array(
            'action'            => '',
            'position'            => '',
            'image_sizes'      => array(),
            'website_url' => $upload_dir['baseurl'],
            'watermark_auto' => get_bloginfo('name'),
        );

        if (isset($_POST['reset-options'])) {
            return $clean;
        }

        $clean['action'] = '';
        if (isset($_POST['save-configuration'])) {
            $clean['action'] = 'save-configuration';
            add_settings_error('general', 'configuration_saved', __('Configuration Saved.'), 'updated');
        }

        if (isset($_POST['token'])) {
            $clean['token'] = $_POST['token'];
        }

        if (isset($dirty['protected_url'])) {
            $clean['protected_url'] = $dirty['protected_url'];
        }

        if (isset($dirty['copyright_owner'])) {
            $clean['copyright_owner'] = $dirty['copyright_owner'];
        }

        if (isset($dirty['masked_url'])) {
            $clean['masked_url'] = $dirty['masked_url'];
        }

        if( isset( $dirty['show_watermarks'] ) ){
            $clean['show_watermarks'] = esc_attr( $dirty['show_watermarks'] );
        }

        if( isset( $dirty['website_url'] ) ){
            $clean['website_url'] = esc_attr( $dirty['website_url'] );
        }

        if( isset( $dirty['watermark_auto'] ) ){
            $clean['watermark_auto'] = esc_attr( $dirty['watermark_auto'] );
        }

        if ( isset( $dirty['image_sizes'] ) ) {
            $image_sizes = self::get_image_sizes();
            foreach ( (array) $dirty['image_sizes'] as $image_size ) {
                if ( array_key_exists( $image_size, $image_sizes ) ) {
                    $clean['image_sizes'][$image_size] = $image_size;
                }
            }
        }
        if ( isset( $dirty['position'] ) && array_key_exists( $dirty['position'], self::get_positions() ) ) {
            $clean['position'] = $dirty['position'];
        }
        return $clean;
    }

    /**
     * Sanitize Settings Status.
     *
     * @param      array     $dirty List of values that may be settings.
     * @return     array     Sanitized array of all recognized settings.
     *
     * @since      2012-04-15
     */
    static function settings_sanitize_status($dirty) {
        $clean = array(
            'action'            => '',
            'token'             => '',
        );

        if (isset($_POST['reset-options'])) {
            return $clean;
        }

        $clean['action'] = '';
        if (isset($_POST['activate-protection'])) {
            $clean['action'] = 'activate-protection';
            add_settings_error('general', 'status_changed', __('Protection Activated.'), 'updated');
        }

        if (isset($_POST['deactivate-protection'])) {
            $clean['action'] = 'deactivate-protection';
            add_settings_error('general', 'status_changed', __('Protection Deactivated.'), 'updated');
        }

        if (isset($_POST['token'])) {
            $clean['token'] = $_POST['token'];
        }

        return $clean;
    }
}
